/* 
 * File:   AliTableView.cpp
 * Author: tg
 * 
 * Created on November 21, 2011, 1:20 PM
 *
 * mrtailor-gui: Qt-based GUI for the program "mrtailor"
 * Copyright (C) 2012, Tim Gruene (tg@shelx.uni-ac.gwdg.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "AliTableView.h"
#include <iostream>


AliTableView::AliTableView(QTableWidget* parent) : QTableWidget(parent) {
    
    charWidth_ = QApplication::fontMetrics().width(QLatin1Char('A'));
    
    this->setEditTriggers(QAbstractItemView::NoEditTriggers);
    this->setFont(QFont("Courier"));
    this->setWordWrap(false);
    this->setShowGrid(true);
    this->horizontalHeader()->setDefaultAlignment(Qt::AlignLeft);
    this->setSelectionMode(QAbstractItemView::NoSelection);
    this->setTextElideMode(Qt::ElideNone);    

    colsWidth();
    
    this->setRowCount(1);
    this->setColumnCount(2);
    
    tabHeaders_.clear();
    tabHeaders_ << "Chains" << "Sequence" ;
    this->setHorizontalHeaderLabels(tabHeaders_);
    
    tabIds_ << "Sequence ID";
    this->setVerticalHeaderLabels(tabIds_);
    this->resizeEvent(NULL);
}


AliTableView::~AliTableView() {
}

int AliTableView::colsWidth()  {
    idsWidth_ = 10;
    seqWidth_ = 100;
    std::map<std::string, std::string>::const_iterator it;

    for (it = ids_and_Sequences_.begin(); it != ids_and_Sequences_.end(); ++it) {
        idsWidth_ = std::max(idsWidth_, it->first.length());
        seqWidth_ = std::max(seqWidth_, it->second.length());
    }

    idsWidth_ *= int (1.2 * charWidth_);
    seqWidth_ *= int (1.2 * charWidth_);
    return idsWidth_;
}

/**
 * Fills the table with sequences
 * @param seqs
 */
void AliTableView::showAlignments(const std::map<std::string, std::string>& seqs) {
    ids_and_Sequences_ = seqs;
    std::map<std::string, std::string>::const_iterator it;
    
    this->clear();

    this->setRowCount(ids_and_Sequences_.size());
    
    colsWidth();
    tabIds_.clear();

    int row(0);
    for (it = ids_and_Sequences_.begin(); it != ids_and_Sequences_.end(); ++it){
        QTableWidgetItem* seq = new QTableWidgetItem (tr(it->second.c_str()));
        tabIds_ << tr(it->first.c_str());
        this->setItem(row, 1, seq);
        ++row;
    }

    this->resizeEvent(NULL);
}

void AliTableView::showMatches(const std::string& id, const std::string& pdbChains) {
    colsWidth();
    if (ids_and_Sequences_.empty()) {
        this->resizeEvent(NULL);
        return;
    }
    int row (0);
    std::map<std::string, std::string>::const_iterator it;
    for (it = ids_and_Sequences_.begin(); it != ids_and_Sequences_.end(); ++it){
        if (id == it->first) {

            QBrush highlitebrush (QColor(Qt::yellow).lighter(160));
            QTableWidgetItem* chainIds = new QTableWidgetItem (tr(pdbChains.c_str()));
            
            this->setItem (row, 0, chainIds);
            if (this->item(row, 0) == NULL) {
                std::cerr << "Item (" << row << ", 0) not set" << std::endl;
                break;
            }
            this->item(row,0)->setBackground(highlitebrush);

            if (this->item(row, 1) == NULL) {
                std::cerr << "Item (" << row << ", 0) not set" << std::endl;
                break;
            }
            this->item(row,1)->setBackground(highlitebrush);
            
            break;
        }
        ++row;
    }
    
    this->resizeEvent(NULL);
}

void AliTableView::resizeEvent(QResizeEvent* /* event */) {

    this->setColumnWidth(0, 8*charWidth_);

    this->setColumnWidth(1, seqWidth_);
    
    this->setHorizontalHeaderLabels(tabHeaders_);
    this->setVerticalHeaderLabels(tabIds_);
}