/* 
 * File:   AliViewer.cpp
 * Author: tg
 * 
 * Created on November 21, 2011, 1:20 PM
 *
 * mrtailor-gui: Qt-based GUI for the program "mrtailor"
 * Copyright (C) 2012, Tim Gruene (tg@shelx.uni-ac.gwdg.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "AliViewer.h"

AliViewer::AliViewer(QPlainTextEdit* parent) : QPlainTextEdit(parent), 
idMarginWidth_(0), chainMarginWidth_(0) {
    idsViewer_ = new QPlainTextEdit("", this);
    chainsViewer_ = new QPlainTextEdit("", this);

    idsViewer_->setReadOnly(true);
    idsViewer_->setLineWrapMode(QPlainTextEdit::NoWrap);
    idsViewer_->setFont(QFont("Courier"));

    chainsViewer_->setReadOnly(true);
    chainsViewer_->setLineWrapMode(QPlainTextEdit::NoWrap);
    chainsViewer_->setFont(QFont("Courier"));
    chainsViewer_->setVisible(false);

    setReadOnly(true);
    setLineWrapMode(QPlainTextEdit::NoWrap);
    setFont(QFont("Courier"));

    chainMarginWidth_ = 2*fontMetrics().width(QLatin1Char('A'));
    idsViewer_ ->setBackgroundRole(QPalette::BrightText);
    chainsViewer_->setBackgroundRole(QPalette::ButtonText);
}


AliViewer::~AliViewer() {
}

int AliViewer::idsWidth() const {
    unsigned  int w(10);
    std::map<std::string, std::string>::const_iterator it;
    
    if (ids_and_Sequences_.empty()) return 0;
    
    for (it = ids_and_Sequences_.begin(); it != ids_and_Sequences_.end(); ++it) {
        if (it->first.length() > w) {
            w = it->first.length();
        }
    }
    w = 25 + idsViewer_->fontMetrics().width(QLatin1Char('A')) * w;
    return w;
}

void AliViewer::resizeEvent(QResizeEvent* /* event */) {
    idMarginWidth_ = idsWidth();
    setViewportMargins(idMarginWidth_, 0, chainMarginWidth_, 0);
    idsViewer_->setGeometry(0, 0, idMarginWidth_, height());
    chainsViewer_->setGeometry(width()-chainMarginWidth_, 0,
            chainMarginWidth_, height());

    if (ids_and_Sequences_.empty()) {
        idsViewer_->setVisible(false);
    }
    else {
        idsViewer_->setVisible(true);
    }
}

void AliViewer::showAlignments(const std::map<std::string, std::string>& seqs) {
    ids_and_Sequences_ = seqs;
    QString idText;
    QString aliText;
    std::map<std::string, std::string>::const_iterator it;
    
    for (it = ids_and_Sequences_.begin(); it != ids_and_Sequences_.end(); ++it){
        idText.append(tr(it->first.c_str()));
        idText.append('\n');
        aliText.append(tr(it->second.c_str()));
        aliText.append('\n');
    }
    idsViewer_->setPlainText(idText);
    setPlainText(aliText);
    
    this->resizeEvent(NULL);
}

void AliViewer::showMatches(const std::string& id, const std::string& pdbChains) {
    QList<QTextEdit::ExtraSelection> selectionList;
    QTextEdit::ExtraSelection selection;
    QTextBlock highlightblock;
    QColor lineColor;
    QString chainText;

    lineColor = QColor(Qt::yellow).lighter(160);

    highlightblock = idsViewer_->document()->firstBlock();

    selection.format.setBackground(lineColor);
    selection.format.setProperty(QTextFormat::FullWidthSelection, true);

    while (QString(id.c_str()) != highlightblock.text()) {
        highlightblock = highlightblock.next();
        chainText.append('\n');
        if (highlightblock == QTextBlock()) {
            return;
        }
    }

    chainText.append(pdbChains.c_str());
    chainsViewer_->setPlainText(chainText);
    chainsViewer_->setVisible(true);
    chainMarginWidth_ = 20 + chainsViewer_->fontMetrics().width(QLatin1Char('A')) * pdbChains.size();

    selection.cursor = QTextCursor(highlightblock);
    selectionList.push_back(selection);
    idsViewer_->setExtraSelections(selectionList);

    selectionList.clear();

    highlightblock = this->document()->firstBlock();
    while (QString(ids_and_Sequences_[id].c_str()) != highlightblock.text()){
        highlightblock = highlightblock.next();
        if (highlightblock == QTextBlock()) {
            return;
        }
    }
    selection.cursor = QTextCursor(highlightblock);
    selectionList.push_back(selection);
    this->setExtraSelections(selectionList);

    this->resizeEvent(NULL);
}
