/* 
 * File:   MRPrepGui.h
 * Author: tg
 *
 * Created on November 7, 2011, 1:04 PM
 *
 * mrtailor-gui: Qt-based GUI for the program "mrtailor"
 * Copyright (C) 2012, Tim Gruene (tg@shelx.uni-ac.gwdg.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MRTAILORGUI_H
#define	MRTAILORGUI_H

#include "PDB.h"
#include "Chain.h"
#include "Sequence.h"
#include "AlignLayout.h"
#include "RunProsmart.h"


#include <QWidget>
#include <map>
#include <string>
#include <vector>

class MRTailorGui: public QWidget {
    Q_OBJECT
private:
    bool inputPDBfile_;
    bool inputAlignment_;
    std::map<std::string, std::string> sequences_;
    PDB* pdb_;
    std::vector<Chain> modifiedChains_;
    Sequence target_;
    Sequence model_;
    std::string output_file_;
    AlignLayout* aliLayout_;
    RunProsmart* runProsmart_;
    QString qscoreFile_;
    int     qscoreCutoff_;

    //! find sequence from alignment in PDB file
    void findSequence();
    
    //! running prosmart
    int callProsmart(const char referenceChain) const;

private slots:
    //! slot for PDB file browser
    void findSequence(QString pdbfile);
    //! slot for Alignment file browser
    void findSequence(const std::map<std::string, std::string>& seqs);
    void runmrtailor();
    void outputfile(QString);
    void setQScoreData(const QString&, int);

public:
    MRTailorGui(QWidget* parent=0);
    ~MRTailorGui();

signals:
    void sequenceMatch(std::string, std::string);

};

#endif	/* MRTAILORGUI_H */

