/* 
 * File:   ProsmartDialog.cpp
 * Author: tg
 * 
 * Created on January 17, 2013, 1:41 PM
 */

#include "ProsmartDialog.h"

ProsmartDialog::ProsmartDialog(QWidget* parent): QWidget(parent) {
    
    refiPDBEdit = new QLineEdit;
    browseRefiPDB = new QPushButton("Browse for PDB file");
    outDirEdit = new QLineEdit;
    browseOutDir = new QPushButton("Browse for Output Directory");
    
    forceSequence_ = new QCheckBox ("Enforce Sequence");
    forceSequence_->setCheckState(Qt::Checked);
    
    connect (browseRefiPDB, SIGNAL (pressed()), this, SLOT (fileBrowsing()));
    connect (browseOutDir, SIGNAL (pressed()), this, SLOT (dirBrowsing()));
    connect (refiPDBEdit, SIGNAL(textChanged(const QString &)), this, SLOT(new_file_slot(const QString&)));
    
    QLabel* pdblabel = new QLabel("PDB for Refinement:", refiPDBEdit);
    QHBoxLayout* lt_refiPDB = new QHBoxLayout();
    lt_refiPDB->addWidget(pdblabel);
    lt_refiPDB->addWidget(refiPDBEdit);
    lt_refiPDB->addWidget(browseRefiPDB);
    
    QLabel* outdirlabel = new QLabel ("Prosmart Output Directory: ", outDirEdit);
    QDir dirinfo;
    QString path (dirinfo.absolutePath());
    path += "/prosmart";
    outDirEdit->setText(path);
    QHBoxLayout* lt_outdir = new QHBoxLayout();
    lt_outdir->addWidget(outdirlabel);
    lt_outdir->addWidget(outDirEdit);
    lt_outdir->addWidget(browseOutDir);
    
    QGridLayout* gridlt = new QGridLayout();
    
    gridlt->addWidget (pdblabel, 0, 0);
    gridlt->addWidget(refiPDBEdit, 0, 1);
    gridlt->addWidget(browseRefiPDB, 0, 2);
    
    gridlt->addWidget (outdirlabel, 1, 0);
    gridlt->addWidget (outDirEdit, 1, 1);
    gridlt->addWidget (browseOutDir, 1, 2);
    
    QVBoxLayout* layout = new QVBoxLayout();
    layout->addLayout(lt_refiPDB);
    layout->addLayout(lt_outdir);

    gridlt->addWidget(forceSequence_);
    
    setLayout(gridlt);
}

ProsmartDialog::~ProsmartDialog() {
}

void ProsmartDialog::nameChangeRefiPDB(const QString& name) {
    refiPDBFilename = name;
}

void ProsmartDialog::nameChangeOutDir(const QString& name) {
    outdirName = name;
}

void ProsmartDialog::fileBrowsing() {
    refiPDBEdit->setText(QFileDialog::getOpenFileName(this, tr("Open PDB file used for refinement"),
            refiPDBFilename, tr("PDB file (*.pdb *.ent)")));
    if (!refiPDBEdit->text().isEmpty()) {
        emit new_file(refiPDBEdit->text());
    }
}

void ProsmartDialog::dirBrowsing() {
    QFileDialog* qfiledialog = new QFileDialog;
    qfiledialog->setFileMode(QFileDialog::DirectoryOnly);

    outDirEdit->setText(qfiledialog->getExistingDirectory(this, tr("Output directory for Prosmart "),
            outdirName));
    if (!outDirEdit->text().isEmpty()) {
        emit new_dir(outDirEdit->text());
    }
}

void ProsmartDialog::new_file_slot(const QString& filename) {
    emit new_file (filename);
}