/* 
 * File:   QScoreInput.cpp
 * Author: tg
 * 
 * Created on February 18, 2012, 2:22 PM
 *
 * mrtailor-gui: Qt-based GUI for the program "mrtailor"
 * Copyright (C) 2012, Tim Gruene (tg@shelx.uni-ac.gwdg.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "QScoreInput.h"
#include "QScores.h"


QScoreInput::QScoreInput(QWidget* parent): QWidget(parent), cutoff_(20) {
    QHBoxLayout* layout = new QHBoxLayout;
    fileEdit_ = new QLineEdit(filename_);
    fileEdit_->setStatusTip(tr("File with scores as created by clustalx."));
    
    QPushButton* browseButton= new QPushButton(tr ("Browse"));
    QSpinBox* cutoffbox      = new QSpinBox ();
    cutoffbox->setRange(0,100);
    cutoffbox->setValue(cutoff_);

    QLabel* fileLabel   = new QLabel(tr("QScore File: "));
    QLabel* cutoffLabel = new QLabel (tr ("Cut-off"));
    
    connect (fileEdit_, SIGNAL(textEdited(const QString)), this, SLOT(nameChange(const QString)));
    connect (browseButton, SIGNAL (pressed()), this, SLOT (fileBrowsing()));
    connect (cutoffbox, SIGNAL(valueChanged(const int)), this, SLOT(cutoffChange(const int)));
    
    layout->addWidget(fileLabel);
    layout->addWidget(fileEdit_);
    layout->addWidget(browseButton);
    layout->addWidget(cutoffbox);
    layout->addWidget(cutoffLabel);
    
    setLayout(layout);
}

QScoreInput::~QScoreInput() {
}

void QScoreInput::fileBrowsing() {
    fileEdit_->setText(QFileDialog::getOpenFileName(this, tr("Open QScore file "),
            filename_, tr("Score file")));
    if (fileEdit_->text().isEmpty()) {
        emit new_file("", 0);
    }
    else {
        emit new_file(fileEdit_->text(), cutoff_);
    }
}

void QScoreInput::cutoffChange(const int newvalue) {
    cutoff_ = newvalue;
    emit new_file(fileEdit_->text(), cutoff_);
}

void QScoreInput::nameChange(const QString& name) {
    filename_ = name;
    emit new_file(fileEdit_->text(), cutoff_);
}
