/* 
 * File:   ReadClustalAln.cpp
 * Author: tg
 * 
 * Created on November 8, 2011, 7:12 PM
 *
 * mrtailor-gui: Qt-based GUI for the program "mrtailor"
 * Copyright (C) 2012, Tim Gruene (tg@shelx.uni-ac.gwdg.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "ReadClustalAln.h"
#include "Exception.h"
#include <fstream>
#include <stdexcept>


ReadClustalAln::ReadClustalAln(const char* filename) throw (guiException::Format()) {
    std::ifstream inp(filename);
    const int linelength (100);
    char line[linelength];
    std::string id, sequence;

    if (! inp.is_open()) {
        throw std::runtime_error("Cannot open file.");
    }

    inp >> id;
    if (id.substr(0, 7) != "CLUSTAL") {
        throw guiException::Format ("Not a CLUSTAL alignment file");
    }
    // discard rest of 'CLUSTAL' line
    inp.getline(line, linelength);

    /*
     * multiple alignments contain marker lines under sequences which must be
     * removed
     */
    while (inp.good()) {
        if (inp.peek() == ' ' || inp.peek() == '\t' || inp.peek() == '\n') {
            inp.getline(line, linelength);
            continue;
        }
        if (! inp.good()) {
            continue;
        }
        inp >> id;
        inp >> sequence;
        sequences_[id] += sequence;
    }
    inp.close();
    
}

ReadClustalAln::~ReadClustalAln() {
}

