/* 
 * File:   ATOM.h
 * Author: tg
 * 
 * Created on October 28, 2011, 3:57 PM
 * 
 * mrtailor: alignment based preparation of PDB files for MR.
 * Copyright (C) 2012, Tim Gruene (tg@shelx.uni-ac.gwdg.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ATOM_H
#define	ATOM_H

#include <string>

/**
 * storage class for ATOM card.
 * residue type, residue number and line number are stored explicitely, otherwise
 * only the ATOM line and ANISOU line are stored altogether
 */
class ATOM {
private:
    std::string atom_card_;
    std::string anisou_card_;
    int residue_number_;
    std::string residue_type_;

public:
    ATOM(): residue_number_(-1), residue_type_("VOID"){};
    ATOM (const std::string atom_card);
    virtual ~ATOM(){};

    //! change residue number for all atoms
    void renumber (unsigned int new_number);
    
    //! fill ATOM card with ANISOU card
    void add_anisou(const std::string& anisou_card)
        {anisou_card_=anisou_card;}

    //! return chain, or '-' if empty card
    char chain () const;
    
    //!return residue number
    int residue_number() const { return residue_number_; }

    //! return residue type
    std::string residue_type() const { return residue_type_; }

    //! shift residue number new = old+delta
    void shift(int delta);

    //! return atom name string
    std::string atom_name() const { return atom_card_.substr(12, 4);}

    //! change the residue name
    void change_residue_name (const std::string& newname);

    //! output of ATOM card
    friend std::ostream& operator << (std::ostream& stream,
                            const ATOM& atom);
};

#endif	/* ATOM_H */

