/* 
 * File:   Chain.h
 * Author: tg
 *
 * Created on October 31, 2011, 9:16 PM
 *
 * mrtailor: alignment based preparation of PDB files for MR.
 * Copyright (C) 2012, Tim Gruene (tg@shelx.uni-ac.gwdg.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CHAIN_H
#define	CHAIN_H

class Sequence;
#include "Residue.h"
#include "ATOM.h"
#include "Sequence.h"

#include <vector>

class QScores;

class Chain {
private:
    char chainID_;
    std::vector<Residue> chain_;

public:
    //! standard constructor
    Chain();
    //! chain from list of ATOMS. Splitting into residues done here
    Chain (const std::vector<ATOM>& atoms);

    //! delete the residue with given residue number
    void remove (unsigned int residue_number);

    //! change residue number at a certain position
    void renumber (unsigned int old_number, unsigned int new_number);

    //! return id
    char id() const { return chainID_; }

    //! return if chain_ is empty
    bool empty() const {return chain_.empty(); }

    //! return if residue numbers are sorted in increasing order
    bool sorted () const;
    
    //! modify this chain according to sequence alignment
    void mrtailor (const Sequence& model_seq, const Sequence& target_seq);
    
    //! modified version of 'mrtailor'
    void force_seq (const std::string& seq);
    
    //! apply scores
    void applyScores (const QScores qscores, int cutOff);
    
    //! number of residues in @c chain_
    int numResidues() const { return chain_.size() ; }

    //! sorting by chain ID
    friend bool operator< (const Chain& c1, const Chain& c2);
    
    //! output of ATOM cards
    friend std::ostream& operator << (std::ostream& stream,
                            const Chain& chain);
};

#endif	/* CHAIN_H */

