/* 
 * File:   PDB.h
 * Author: tg
 *
 * Created on October 30, 2011, 5:48 PM
 *
 * mrtailor: alignment based preparation of PDB files for MR.
 * Copyright (C) 2012, Tim Gruene (tg@shelx.uni-ac.gwdg.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef PDB_H
#define	PDB_H

// forward declaration
class Sequence;
#include "Chain.h"

#include <string>
#include <vector>
#include <iostream>

class PDB {
private:
    const std::string filename_;
    //! linewise storage of PDB-file
    std::vector<std::string> original_file_;
    //! coordinate information
    std::vector<Chain> chains_;
    //! sequences, per chain (only ATOM, not HETATM)
    std::vector<Sequence> sequences_;
    //! vector with coverage fraction (see @c find_similar_chains))
    std::vector<double> coverages_;
    
    //! put the sequences from PDB-file into sequences_;
    void sequence_extract();

    //! mutate residue to @c aa and strip to ALA
    void mutate_and_strip (int residue, const char aa);
    
public:
    PDB(const char* filename);

    //! find chains in PDB file corresponding to Sequence
    std::string find_chains (const Sequence& seq) const;
    
    //! find chains similar to sequence
    std::string find_similar_chains (const Sequence& seq, double perc_coverage);
    
    //! fix PDB file w.r.t. sequence alignment
    void polish (const Sequence& target_seq, const Sequence& pdb_seq);

    //! return the chain with id @c id
    Chain chain(const char id) const;
    
    //! replace chain id with chain
    void replace (const char id, const Chain& newchain);

    //! write PDB file with modified chains replacing original ones
    void writePDB (std::vector<Chain> newChains,
                std::ostream& outp) const;
    
    //! return filename for this PDB
    std::string filename () const { return filename_; }
    
    //! return table of chainIDs and fractions from 'find_similar_chains'
    std::string printFractions() const;
};

#endif	/* PDB_H */

