/* 
 * File:   Residue.h
 * Author: tg
 *
 * Created on October 28, 2011, 6:14 PM
 *
 * mrtailor: alignment based preparation of PDB files for MR.
 * Copyright (C) 2012, Tim Gruene (tg@shelx.uni-ac.gwdg.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef RESIDUE_H
#define	RESIDUE_H

#include <list>
#include <string>

#include "ATOM.h"

class Residue {
    int residue_number_;
    char single_residue_letter_;
    std::list<ATOM> atoms_;
public:
    //! non-existing Residue

    Residue() : residue_number_(-1) {
    };
    //! positioned residue, but empty
    Residue(int resnumber);
    //! residue from list of atoms
    Residue(const std::list<ATOM> atoms);

    ~Residue() {};

    //! make residue an alanine, and rename it to 'resname'
    void alanine(const std::string& resname);

    //! shift residue number by @c delta
    void shift(int delta);

    //! change residue number
    void renumber(unsigned int new_number);

    //! return residue number

    int residue_number() const {
        return residue_number_;
    }

    //! return residue letter
    char single_residue_letter () const;
    //! output of ATOM cards
    friend std::ostream & operator <<(std::ostream& stream,
            const Residue& residue);
};

#endif	/* RESIDUE_H */

