/* 
 * File:   Sequence.h
 * Author: tg
 *
 * Created on October 29, 2011, 11:35 AM
 *
 * mrtailor: alignment based preparation of PDB files for MR.
 * Copyright (C) 2012, Tim Gruene (tg@shelx.uni-ac.gwdg.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SEQUENCE_H
#define	SEQUENCE_H

#include <string>
#include <ostream>
#include <vector>

class Sequence {
private:
    std::string id_;
    std::string sequence_;
    std::vector<int> sequence_numbers_;
    mutable std::vector<int>::const_iterator it_search_index_;

    //! set up array with sequence numbers after sequence has been initialised
    void sequence_numbering();
public:
    Sequence();
    Sequence(const char* filename, const std::string& id);
    Sequence (const std::string& id, const std::string& seq);
    ~Sequence();

    //! remove all gaps ('-')
    void strip_gaps ();

    void append(const std::string& tail) {sequence_.append(tail); }
    int length() const {return sequence_.length();}
    int sequence_length() const { return length() - gaps();}
    std::string id() const { return id_;}
    std::string sequence() const { return sequence_; }

    //! count gaps
    unsigned int gaps() const;

    //! check for identiy
    bool contains (const Sequence& other) const;
    

    //! return the character at given position
    char at(unsigned int where) const { return sequence_.at(where); }
    //! return character where it_search_index points to
    char current () const { return sequence_.at(*it_search_index_);}

    //! return sequence number at position @c idex
    unsigned int sequence_number(unsigned int idx) const
                    {return sequence_numbers_.at(idx); }
    
    //! find the sequence number corresponding to residue number
    int inc_search_resnum (int resnumber) const;

    //! reset search index
    void search_reset() { it_search_index_ = sequence_numbers_.begin(); }

    //! count gaps, matches and mismatches of overlaid other
    friend void count (const Sequence& one, const Sequence& other, 
        int& match, int& misses, int& gaps, int& inserts);

    //! output
    friend std::ostream& operator << (std::ostream& stream,
                            const Sequence& sequence);

};

// declaration for other classes
void count (const Sequence& one, const Sequence& other, 
        int& match, int& misses, int& gaps, int& inserts);

#endif	/* SEQUENCE_H */

