/* 
 * File:   conversions.cpp
 * Author: tg
 * 
 * Created on October 28, 2011, 3:57 PM
 *
 * mrtailor: alignment based preparation of PDB files for MR.
 * Copyright (C) 2012, Tim Gruene (tg@shelx.uni-ac.gwdg.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "conversions.h"
#include <iostream>

/**
 * turn a 3-letter code into the corresponding 1-letter code
 * relies on the two arrays in conversions.h to correspond to each other
 * not proper error handling if @c aa is not in the listed codes
 * @param aa
 * @return single letter code for 'aa'
 */
char Conversions::three2single(const std::string& aa) {
    int idx(0);
    int maxindex = sizeof(Conversions::ThreeLetterCodes)/
        sizeof(Conversions::ThreeLetterCodes[0]);

    while (idx < maxindex) {
        if (ThreeLetterCodes[idx] == aa) {
            return SingleLetterCodes[idx];
        }
        ++idx;
    }
    //! should throw an error here
//    std::cerr << "*** Lazy coding: we should not get here, error handling "
//            << "required\n";
//    std::cerr << " 3-letter to 1-letter code for " << aa << " requested \n";
    return '?';
}

std::string Conversions::single2three(char aa) {
    int idx(0);
    int maxindex = sizeof(Conversions::SingleLetterCodes)/
        sizeof(Conversions::SingleLetterCodes[0]);

    while (idx < maxindex) {
        if (SingleLetterCodes[idx] == aa) {
            return ThreeLetterCodes[idx];
        }
        ++idx;
    }
//    std::cerr << "*** Lazy coding: we should not get here, error handling "
//            << "required\n";
//    std::cerr << " 1-letter to 3-letter code for " << aa << " requested \n";
    return "UNK";
}
