/* 
 * File:   conversions.h
 * Author: tg
 *
 * Created on October 30, 2011, 7:28 PM
 * 
 * mrtailor: alignment based preparation of PDB files for MR.
 * Copyright (C) 2012, Tim Gruene (tg@shelx.uni-ac.gwdg.de)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CONVERSIONS_H
#define	CONVERSIONS_H

#include <string>

namespace Conversions {
    //! convert single residue name to three-letter code
    std::string single2three(char aa);
    char three2single(const std::string& aa);
    //! Three letter codes for amino acids
    const char* const ThreeLetterCodes [] = {
        "ALA",
        "ARG",
        "ASN",
        "ASP",
        "CYS",
        "GLN",
        "GLU",
        "GLY",
        "HIS",
        "ILE",
        "LEU",
        "LYS",
        "MET",
        "PHE",
        "PRO",
        "SER",
        "THR",
        "TRP",
        "TYR",
        "VAL"
    };
    //! Single lette codes for amino acids, same order as above
    const char SingleLetterCodes [] = {
        'A',
        'R',
        'N',
        'D',
        'C',
        'Q',
        'E',
        'G',
        'H',
        'I',
        'L',
        'K',
        'M',
        'F',
        'P',
        'S',
        'T',
        'W',
        'Y',
        'V'
    };
    //! enumerator to access three letter and one letter code arrays

    enum AA_Index {
        A,
        R,
        N,
        D,
        C,
        Q,
        E,
        G,
        H,
        I,
        L,
        K,
        M,
        F,
        P,
        S,
        T,
        W,
        Y,
        V
    };

}

#endif	/* CONVERSIONS_H */

